@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "verilog-ts-mode" "0.5.0"
+(define-package "verilog-ts-mode" "20251008.2041"
   "Verilog Tree-sitter major mode."
   '((emacs        "29.1")
     (verilog-mode "2024.3.1.121933719"))
